==> office-ui-fabric-react-0.50.0.tgz: package/lib-amd/demo/pages/OrgChartPage/OrgChartPage.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../../index', '../../components/index', './examples/OrgChart.Basic.Example', '../../utilities/pageroute', '../../components/App/AppState'], function (require, exports, React, index_1, index_2, OrgChart_Basic_Example_1, pageroute_1, AppState_1) {
    "use strict";
    var OrgChartBasicExampleCode = require('./examples/OrgChart.Basic.Example.tsx');
    var OrgChartPage = (function (_super) {
        __extends(OrgChartPage, _super);
        function OrgChartPage() {
            _super.call(this);
            this._url = pageroute_1.getPageRouteFromState(AppState_1.AppState, 'Basic components', 'OrgChart');
        }
        OrgChartPage.prototype.render = function () {
            return (React.createElement(index_2.ComponentPage, {title: 'OrgChart', componentName: 'OrgChartExample', exampleCards: [
                React.createElement(index_2.ExampleCard, {title: 'OrgChart', code: OrgChartBasicExampleCode}, React.createElement(OrgChart_Basic_Example_1.OrgChartBasicExample, null))
            ], overview: React.createElement("div", null, React.createElement(index_1.Link, {target: '_blank', href: 'http://dev.office.com/fabric/components/OrgChart'}, "OrgCharts"), React.createElement("span", null, " are used to render an org chart.")), route: this._url}));
        };
        return OrgChartPage;
    }(React.Component));
    exports.OrgChartPage = OrgChartPage;
});

==> office-ui-fabric-react-0.52.2.tgz: package/lib-amd/demo/pages/OrgChartPage/OrgChartPage.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../../index', '../../components/index', './examples/OrgChart.Basic.Example', '../../utilities/pageroute', '../../components/App/AppState'], function (require, exports, React, index_1, index_2, OrgChart_Basic_Example_1, pageroute_1, AppState_1) {
    "use strict";
    var OrgChartBasicExampleCode = require('./examples/OrgChart.Basic.Example.tsx');
    var OrgChartPage = (function (_super) {
        __extends(OrgChartPage, _super);
        function OrgChartPage() {
            _super.call(this);
            this._url = pageroute_1.getPageRouteFromState(AppState_1.AppState, 'Basic components', 'OrgChart');
        }
        OrgChartPage.prototype.render = function () {
            return (React.createElement(index_2.ComponentPage, {title: 'OrgChart', componentName: 'OrgChartExample', exampleCards: [
                React.createElement(index_2.ExampleCard, {title: 'OrgChart', code: OrgChartBasicExampleCode}, React.createElement(OrgChart_Basic_Example_1.OrgChartBasicExample, null))
            ], overview: React.createElement("div", null, React.createElement(index_1.Link, {target: '_blank', href: 'http://dev.office.com/fabric/components/OrgChart'}, "OrgCharts"), React.createElement("span", null, " are used to render an org chart.")), route: this._url, isHeaderVisible: this.props.isHeaderVisible}));
        };
        return OrgChartPage;
    }(React.Component));
    exports.OrgChartPage = OrgChartPage;
});
